==> wurld-0.1.tar.gz: wurld-0.1/src/gameobjs/quadramid.py <==
#==============================================================================
#
#  $Id$
#
"""
   Creates a moving pyramid with a flattened top.
"""
#
#  Copyright (C) 2006 Michael A. Muller
#
#  Permission is granted to use, modify and redistribute this code,
#  providing that the following conditions are met:
#
#  1) This copyright/licensing notice must remain intact.
#  2) If the code is modified and redistributed, the modifications must 
#  include documentation indicating that the code has been modified.
#  3) The author(s) of this code must be indemnified and held harmless
#  against any damage resulting from the use of this code.
#
#  This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
#  warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
#
#==============================================================================

import wurld

def makeQuadramid():
   model = wurld.createModel()
   v = wurld.createVector
   q = wurld.createQuad

   blb = v(-2.5, 0, -2.5)
   blf = v(-2.5, 0, 2.5)
   brb = v(2.5, 0, -2.5)
   brf = v(2.5, 0, 2.5)
   tlb = v(-1, 5, -1)
   tlf = v(-1, 5, 1)
   trb = v(1, 5, -1)
   trf = v(1, 5, 1)
   stone = wurld.createTextureMaterial(wurld.createTexture('stucco.png'), 10, 10)

   # bottom
   model.addPoly(q(blb, blf, brf, brb, stone))

   # front
   model.addPoly(q(tlf, trf, brf, blf, stone))

   # back
   model.addPoly(q(trb, tlb, blb, brb, stone))

   # left 
   model.addPoly(q(tlb, tlf, blf, blb, stone))

   # right
   model.addPoly(q(trf, trb, brb, brf, stone))

   # top
   model.addPoly(q(tlb, trb, trf, tlf, stone))

   return model

def myCallback(engine, pythonObj):

   pos = moveable.getPosition()
   vel = moveable.getVelocity()
   changeVelocity = False
   if pos.y < 0 or pos.y > 20:
      vel.y = vel.y * -1
      changeVelocity = True

   if pos.x > 20 or pos.x < -20:
      vel.x = vel.x * -1
      changeVelocity = True

   if pos.z > 20 or pos.z < -20:
      vel.z = vel.z * -1
      changeVelocity = True

   if changeVelocity:
      moveable.setVelocity(vel)
   

model = makeQuadramid()
obj = wurld.createPythonObject()
moveable = wurld.createMoveable()
moveable.setModel(model)
moveable.setPosition(wurld.createVector(0, 18, 0))
moveable.setVelocity(wurld.createVector(10, 10, 10))
obj.setMoveable(moveable)
wurld.getGameEngine().addGameObject(obj)
wurld.getGameEngine().addRenderableObject(obj)
obj.setEngineFrameCallback(myCallback)

==> wurld-0.2.tar.gz: wurld-0.2/src/gameobjs/quadramid.py <==
#==============================================================================
#
#  $Id$
#
"""
   Creates a moving pyramid with a flattened top.
"""
#
#  Copyright (C) 2006 Michael A. Muller
#
#  Permission is granted to use, modify and redistribute this code,
#  providing that the following conditions are met:
#
#  1) This copyright/licensing notice must remain intact.
#  2) If the code is modified and redistributed, the modifications must 
#  include documentation indicating that the code has been modified.
#  3) The author(s) of this code must be indemnified and held harmless
#  against any damage resulting from the use of this code.
#
#  This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
#  warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
#
#==============================================================================

import wurld

def makeQuadramid():
   model = wurld.createModel()
   v = wurld.createVector
   q = wurld.createQuad

   blb = v(-2.5, 0, -2.5) *2
   blf = v(-2.5, 0, 2.5) *2
   brb = v(2.5, 0, -2.5) *2
   brf = v(2.5, 0, 2.5) *2
   tlb = v(-1, 5, -1) *2
   tlf = v(-1, 5, 1) *2
   trb = v(1, 5, -1) *2
   trf = v(1, 5, 1) *2
   stone = wurld.createTextureMaterial(wurld.createTexture('stucco.png'), 10, 10)

   # bottom
   model.addPoly(q(blf, blb, brb, brf, stone))

   # front
   model.addPoly(q(trf, tlf, blf, brf, stone))

   # back
   model.addPoly(q(tlb, trb, brb, blb, stone))

   # left 
   model.addPoly(q(tlf, tlb, blb, blf, stone))

   # right
   model.addPoly(q(trb, trf, brf, brb, stone))

   # top
   model.addPoly(q(trb, tlb, tlf, trf, stone))

   return model

def myCallback(engine, pythonObj):

   pos = moveable.getPosition()
   vel = moveable.getVelocity()
   changeVelocity = False
   if pos.y < 0 or pos.y > 20:
      vel.y = vel.y * -1
      changeVelocity = True

   if pos.x > 20 or pos.x < -20:
      vel.x = vel.x * -1
      changeVelocity = True

   if pos.z > 20 or pos.z < -20:
      vel.z = vel.z * -1
      changeVelocity = True

   if changeVelocity:
      moveable.setVelocity(vel)
   

model = makeQuadramid()
obj = wurld.createPythonObject()
moveable = wurld.createMoveable()
moveable.setModel(model)
moveable.setPosition(wurld.createVector(0, 18, 0))
moveable.setVelocity(wurld.createVector(10, 10, 10))
obj.setMoveable(moveable)
wurld.getGameEngine().addGameObject(obj)
wurld.getGameEngine().addRenderableObject(obj)
obj.setEngineFrameCallback(myCallback)
